@@ -62,7 +62,7 @@
                     <?php if (get_field('header_job_search_from_shortcode') != '') : ?>
                         <form role="search" method="get" action="<?php echo site_url(); ?>/jobs" class="header-search-form">
                             <div class="form-group">
-                                <input type="text" class="form-control" name="keyword" placeholder="Job title, Keyword">
+                                <input type="text" class="form-control" name="keyword" placeholder="test">
                                 <input type="text" class="form-control" name="location" placeholder="City, town, postal code">
                                 <button type="submit" class="btn btn-primary form-control">Search Jobs →</button>
                             </div>
